==> onos-yang-serializers-xml-2.3-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkunderlayattributes/underlaybackuppath/PathElementKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkunderlayattributes.underlaybackuppath;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of pathElement.
 */
public class PathElementKeys implements KeyInfo<DefaultPathElement> {
    protected long pathElementId;
    /**
     * Returns the attribute pathElementId.
     *
     * @return pathElementId value of pathElementId
     */
    public long pathElementId() {
        return pathElementId;
    }

    /**
     * Sets the value to attribute pathElementId.
     *
     * @param pathElementId value of pathElementId
     */
    public void pathElementId(long pathElementId) {
        this.pathElementId = pathElementId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(pathElementId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof PathElementKeys) {
            PathElementKeys other = (PathElementKeys) obj;
            return
                Objects.equals(pathElementId, other.pathElementId);
        }
        return false;
    }
}

==> onos-yang-serializers-xml-2.6.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkunderlayattributes/underlaybackuppath/PathElementKeys.java <==
/*
 * Copyright 2019-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkunderlayattributes.underlaybackuppath;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of pathElement.
 */
public class PathElementKeys implements KeyInfo<DefaultPathElement> {
    protected long pathElementId;
    /**
     * Returns the attribute pathElementId.
     *
     * @return pathElementId value of pathElementId
     */
    public long pathElementId() {
        return pathElementId;
    }

    /**
     * Sets the value to attribute pathElementId.
     *
     * @param pathElementId value of pathElementId
     */
    public void pathElementId(long pathElementId) {
        this.pathElementId = pathElementId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(pathElementId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof PathElementKeys) {
            PathElementKeys other = (PathElementKeys) obj;
            return
                Objects.deepEquals(pathElementId, other.pathElementId);
        }
        return false;
    }
}
